spol
====

A package to check various functions offered by Sindh Police.


Details
-------

Taps into the Sindh Police database.

Package Usage
-------------

import spol

\# check complaint

spol.check_complaint(1)

spol.list_hospitals()

spol.list_units()

spol.list_unit(3)
